<!DOCTYPE html>
<html>
<head>
    <title>Friendship</title>
</head>
<body>
{% block header %}
    {% include 'header.html' %}
{% endblock header %}
{% block content %}{% endblock content %}
</body>
</html>
