{% load url from future %}
<ul>
{% for friendship_request in requests %}
    <li>{{ friendship_request.from_user }} to {{ friendship_request.to_user }} <a href="{% url 'friendship_requests_detail' friendship_request.id %}">view</a></li>
{% empty %}
</ul>
<div>no requests :(</div>
{% endfor %}
